Package: PMwR
Type: Package
Title: Portfolio Management with R
Version: 1.2-0
Date: 2025-12-17
Maintainer: Enrico Schumann <es@enricoschumann.net>
Authors@R: person(given = "Enrico", family = "Schumann",
                  role  = c("aut", "cre"),
                  email = "es@enricoschumann.net",
                  comment = c(ORCID = "0000-0001-7601-6576"))
Description: Tools for the practical management of financial
  portfolios: backtesting investment and trading strategies,
  computing profit/loss and returns, analysing trades,
  handling lists of transactions, reporting, and more.  The
  package provides a small set of reliable, efficient and
  convenient tools for processing and analysing
  trade/portfolio data.  The manual provides all the details;
  it is available from
  <https://enricoschumann.net/R/packages/PMwR/manual/PMwR.html>.
  Examples and descriptions of new features are provided at
  <https://enricoschumann.net/notes/PMwR/>.
Imports: NMOF, datetimeutils, fastmatch, orgutils, parallel, textutils,
        utils, zoo
Suggests: crayon, rbenchmark, tinytest
Depends: R (>= 3.5)
License: GPL-3
LazyLoad: yes
LazyData: yes
ByteCompile: yes
URL: https://enricoschumann.net/PMwR/ ,
        https://git.sr.ht/~enricoschumann/PMwR ,
        https://gitlab.com/enricoschumann/PMwR ,
        https://github.com/enricoschumann/PMwR
NeedsCompilation: no
Packaged: 2025-12-17 13:59:15 UTC; es19
Author: Enrico Schumann [aut, cre] (ORCID:
    <https://orcid.org/0000-0001-7601-6576>)
Repository: CRAN
Date/Publication: 2025-12-17 14:30:02 UTC
Built: R 4.6.0; ; 2026-04-27 11:38:53 UTC; unix
