importFrom("NMOF", "drawdown")
importFrom("NMOF", "pm")

importFrom("zoo",
           as.zoo,
           as.Date.yearmon, as.Date.yearqtr,
           coredata,
           index,
           zoo)

importFrom(orgutils, toOrg)
importFrom(textutils, strexp)
importFrom(textutils, spaces)
importFrom(textutils, toHTML)
importFrom(textutils, toText)
importFrom(textutils, valign)
importFrom(datetimeutils, end_of_month)
importFrom(datetimeutils, end_of_year)
importFrom(datetimeutils, first_of_month)
importFrom(datetimeutils, roundPOSIXt)
importFrom(datetimeutils, timegrid)
importFrom("fastmatch", fmatch)

importFrom("grDevices",
           "grey")
importFrom("graphics",
           "abline", "axis", "hist", "lines", "par", "plot")
importFrom("stats",
           "aggregate", "approx", "quantile", "runif", "sd",
           "time", "uniroot", "window")
importFrom("utils",
           "browseURL", "capture.output", "setTxtProgressBar",
           "str", "txtProgressBar",
           "head", "tail", "toLatex",
           "write.table")

importFrom(parallel, "clusterExport")

export(
    ## .expand,
    .pl,
    .pl_stats,
    .returns,
    ## .tree,
    NAVseries,
    as.NAVseries,
    as.journal,
    btest,
    close_on_first,
    div_adjust,
    drawdowns,
    "instrument<-",
    instrument,
    is.journal,
    is_valid_ISIN,
    is_valid_SEDOL,
    journal,
    limit,
    pl,
    plotTradingHours,
    plot_trading_hours,
    position,
    pricetable,
    q32,
    quote32,
    rc,
    rebalance,
    replace_weight,
    returns,
    scale1,
    scale_to_unity,
    scale_trades,
    split_adjust,
    split_trades,
    streaks,
    tw_exposure,
    unit_prices,
    valuation
    )

## S3method(`[`, position)
S3method(Ops, position)
S3method(Ops, quote32)
S3method(`+`, quote32)
S3method(`-`, quote32)
S3method(`[<-`, journal)
S3method(`[<-`, pricetable)
S3method(`[`, journal)
S3method(`[`, pricetable)
S3method(`instrument<-`, NAVseries)
S3method(`instrument<-`, journal)
S3method(`instrument<-`, pricetable)
S3method(`names<-`, pricetable)
S3method(aggregate, journal)
S3method(all.equal, journal)
S3method(as.NAVseries, NAVseries)
S3method(as.NAVseries, btest)
S3method(as.NAVseries, zoo)
S3method(as.data.frame, journal)
S3method(as.data.frame, p_returns)
S3method(as.data.frame, pl)
S3method(as.data.frame, position)
S3method(as.data.frame, summary.NAVseries)
S3method(as.journal, data.frame)
S3method(as.journal, default)
S3method(as.journal, journal)
S3method(as.journal, list)
S3method(as.journal, position)
S3method(as.journal, rebalance)
S3method(as.matrix, p_returns)
S3method(as.matrix, position)
S3method(as.matrix, pricetable)
S3method(as.zoo, NAVseries)
S3method(as.zoo, p_returns)
S3method(as.zoo, position)
S3method(c, journal)
S3method(drawdowns, NAVseries)
S3method(drawdowns, default)
S3method(drawdowns, zoo)
S3method(head, journal)
S3method(instrument, NAVseries)
S3method(instrument, journal)
S3method(instrument, position)
S3method(instrument, pricetable)
S3method(journal, btest)
S3method(journal, default)
S3method(journal, position)
S3method(length, journal)
S3method(lines, NAVseries)
S3method(lines, btest)
S3method(names, pricetable)
S3method(pl, btest)
S3method(pl, data.frame)
S3method(pl, default)
S3method(pl, journal)
S3method(pl, pl)
S3method(plot, NAVseries)
S3method(plot, btest)
S3method(position, btest)
S3method(position, data.frame)
S3method(position, default)
S3method(position, journal)
S3method(pricetable, default)
S3method(pricetable, zoo)
S3method(print, NAVseries)
S3method(print, btest)
S3method(print, journal)
S3method(print, p_returns)
S3method(print, p_returns_monthly)
S3method(print, pl)
S3method(print, position)
S3method(print, pricetable)
S3method(print, quote32)
S3method(print, rebalance)
S3method(print, summary.NAVseries)
S3method(print, summary.journal)
S3method(returns, NAVseries)
S3method(returns, data.frame)
S3method(returns, default)
S3method(returns, zoo)
S3method(scale1, NAVseries)
S3method(scale1, default)
S3method(scale1, zoo)
S3method(sort, journal)
S3method(str, journal)
S3method(streaks, NAVseries)
S3method(streaks, default)
S3method(streaks, zoo)
S3method(subset, journal)
S3method(summary, NAVseries)
S3method(summary, journal)
S3method(t, p_returns)
S3method(tail, journal)
S3method(toHTML, p_returns)
S3method(toHTML, p_returns_monthly)
S3method(toHTML, position)
S3method(toLatex, p_returns)
S3method(toLatex, p_returns_monthly)
S3method(toLatex, summary.NAVseries)
S3method(toOrg, journal)
S3method(toText, p_returns)
S3method(valuation, default)
S3method(valuation, journal)
S3method(valuation, position)
S3method(window, NAVseries)
